.DistributionsVisualizer{display:flex;flex-direction:column;justify-content:space-between;height:100%;overflow:hidden}.DistributionsVisualizer .highcharts-subtitle{font-style:normal;font-weight:650;color:#1c2852!important;font-family:"Inter",sans-serif!important}
/*# sourceMappingURL=DistributionsVisualizer.css?version=afa4407d71d68b638e6f.map */