.AppBar{display:flex;align-items:center;min-height:2.5rem;max-height:2.5rem;border-bottom:.0625rem solid #e8f1fc;border-left:.0625rem solid #e8f1fc;border-right:.0625rem solid #e8f1fc;padding-left:1.5rem;background:#fff;z-index:1}.AppBar__title{flex:1 1;text-transform:uppercase;letter-spacing:.07em}.AppBar__content{display:flex;align-items:center}.AppBar__content--disabled{pointer-events:none;opacity:.5}.NotificationContainer .MuiAlert-outlinedSuccess{border:.0625rem solid #2bc784}.NotificationContainer .MuiAlert-outlinedError{border:.0625rem solid #e64e48}.NotificationContainer .MuiPaper-root{background:#fff;height:4rem;display:flex;align-items:center;border-radius:.375rem}.NotificationContainer .MuiPaper-root .MuiAlert-icon{padding:0}.NotificationContainer .MuiPaper-root .MuiAlert-icon svg{width:2.375rem;height:2.375rem}.NotificationContainer .MuiPaper-root .MuiAlert-action{display:flex;align-items:flex-start;height:100%}.NotificationContainer .MuiPaper-root .MuiAlert-action .MuiSvgIcon-fontSizeSmall{font-size:1.05rem;fill:#1c2852}.NotificationContainer__contentBox__severity{font-weight:550;font-size:.875rem;text-transform:capitalize;color:#1c2852}.NotificationContainer__contentBox__message{font-weight:350;font-size:.875rem;color:#1c2852}.ConfirmModal .MuiBackdrop-root{background-color:rgba(0,0,0,.4)}.ConfirmModal .MuiPaper-rounded{border-radius:6px}.ConfirmModal .MuiPaper-elevation10{box-shadow:0 2px 4px #767a80}.ConfirmModal__Body{min-width:384px;padding:24px}.ConfirmModal__Body .ConfirmModal__Title__Container{display:flex;align-items:center;margin-bottom:12px}.ConfirmModal__Close__Icon{position:absolute;right:10px;top:10px}.ConfirmModal__Icon{display:flex;justify-content:center;align-items:center;width:32px;height:32px;margin-right:16px;border-radius:50%}.ConfirmModal__Icon .Icon__container{font-size:14px}.ConfirmModal__CancelButton{margin-right:10px;color:#1c2852}.ConfirmModal__Footer{padding:16px;margin:0 8px;border-top:1px solid #dee6f3;display:flex;justify-content:flex-end;align-items:center}.ConfirmModal__error .ConfirmModal__Icon{background-color:#fdeded}.ConfirmModal__error .ConfirmModal__Icon .Icon__container{color:#e64e48}.ConfirmModal__error .ConfirmModal__ConfirmButton{background-color:#e64e48}.ConfirmModal__warning .ConfirmModal__Icon{background-color:#fffae6}.ConfirmModal__warning .ConfirmModal__Icon .Icon__container{color:#fc0}.ConfirmModal__warning .ConfirmModal__ConfirmButton{background-color:#fc0}.ConfirmModal__success .ConfirmModal__Icon{background-color:#eaf9f3}.ConfirmModal__success .ConfirmModal__Icon .Icon__container{color:#2bc784}.ConfirmModal__success .ConfirmModal__ConfirmButton{background-color:#2bc784}.ConfirmModal__info .ConfirmModal__Icon{background-color:#e8f1fc}.ConfirmModal__info .ConfirmModal__Icon .Icon__container{color:#1473e6}.ConfirmModal__info .ConfirmModal__ConfirmButton{background-color:#1473e6}.CodeBlock{background:#f2f3f4;border-radius:.375rem;padding:1em 3em 1em 1em;position:relative;min-height:3.5rem;display:flex;align-items:center;overflow:auto}.CodeBlock pre{margin:0;font-style:normal;font-weight:450;font-size:15px;line-height:1.3125em;overflow:auto;font-family:"Inconsolata",monospace;font-variation-settings:"wdth" 84}.CodeBlock__copy__button{top:.75rem;right:1rem;color:#414b6d;display:inline-block;cursor:pointer;position:absolute;align-items:center;justify-content:center}.BookmarkCard{position:relative;display:flex;flex-direction:column;border:.0625rem solid #dee6f3;border-radius:.5rem;padding:1.5rem;margin-bottom:1rem}.BookmarkCard__delete{margin-left:.25rem}.BookmarkCard__top{flex:1 1}.BookmarkCard__top p{margin-top:.25rem;font-weight:350;font-size:.75rem}.BookmarkCard__description{max-width:100%;word-break:break-all}.BookmarkCard__actionButtonsBox{display:flex;align-items:flex-start;justify-content:center}.BookmarkCard__titleBox__section{display:flex;justify-content:space-between}.BookmarkCard__titleBox__section__container{display:flex;max-width:calc(100% - 14rem);margin-bottom:.625rem}.BookmarkCard__titleBox__section__container__title{width:100%;word-break:break-all;cursor:default}.BookmarkCard__titleBox__section__container__iconBox{height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;margin-top:.125rem}.BookmarkCard__titleBox__section__container__iconBox i{margin-right:.5rem;margin-top:.125rem}.BookmarkCard__titleBox__section a{text-decoration:none}.BookmarkCard__bottom{margin-top:.75rem}.BookmarkCard__bottom strong{color:#243969;margin-right:.5rem}.BookmarkCard__selected__metrics{margin-top:.875rem;width:100%;white-space:nowrap;overflow:auto;padding:.125rem 0}.BookmarkCard__selected__metrics .Badge{margin-right:.5rem}.BookmarkCard:last-child{margin-bottom:0}.Bookmarks{height:100%}.Bookmarks__appBar{width:100%}.Bookmarks__title{margin:.5em 0;padding:0;color:#1473e6}.Bookmarks__container{overflow-y:auto;height:calc(100vh - 40px)}.Bookmarks__list{padding:2rem 1.5em 2em}
/*# sourceMappingURL=bookmarks.css?version=bb8398159f47e2444b6c.map */