(this.webpackJsonpui_v2=this.webpackJsonpui_v2||[]).push([[19],{1992:function(a,e,s){"use strict";s.r(e);var t=s(0),i=s.n(t),n=s(74),r=s(292),c=s(388),u=s(11),b=s(411),l=s(17),m=s(14),j=s(1);function o(a){var e=a.runParams,s=a.isRunInfoLoading;return i.a.useEffect((function(){m.a(l.a.runDetails.tabs.params.tabView)}),[]),Object(j.jsx)(u.a,{children:Object(j.jsx)(r.a,{isLoading:s||!e,className:"RunDetailTabLoader",height:"100%",children:n.a.isEmpty(e)?Object(j.jsx)(c.a,{size:"xLarge",className:"RunDetailTabLoader",title:"No Params"}):Object(j.jsx)("div",{className:"RunDetailParamsTabWrapper",children:Object(j.jsx)("div",{className:"RunDetailParamsTab",children:Object(j.jsx)(b.a,{src:n.a.omit(e,"__system_params")})})})})})}e.default=Object(t.memo)(o)}}]);
//# sourceMappingURL=RunDetailParamsTab.js.map?version=22545c50e9ea48819ecb