.RunDetailLogsTabWrapper{overflow:hidden;height:100%;max-height:100%}.RunDetailLogsTabWrapper .RunDetailLogsTab{border-left:.0625rem solid #dee6f3;border-right:.0625rem solid #dee6f3;height:100%;background-color:#fff}.RunDetailLogsTabWrapper .RunDetailLogsTab .Logs{height:100%;overflow-y:auto;overflow-x:auto;border-radius:.375rem}.RunDetailLogsTabWrapper .RunDetailLogsTab .Logs__wrapper{width:100%;height:100%;position:relative}.RunDetailLogsTabWrapper .RunDetailLogsTab .Logs__wrapper .overlay{display:none;height:3.125rem;width:100%;background:#fff;position:absolute;top:0;left:0}.RunDetailLogsTabWrapper .RunDetailLogsTab .Logs__wrapper .loading{display:flex;justify-content:center;align-items:center}.LogRow__line{color:#333;font-size:.875rem;padding:0 .75rem;font-family:"Inconsolata",monospace;font-variation-settings:"wdth" 82;width:100%;line-height:1.08;display:block;height:15px}.LogRecordItem__title{align-items:center;display:flex;padding:0 1.5rem}.LogRecordItem__title .Icon__container{border-radius:50%;background-color:#e8f1fc;margin-right:.25rem;color:#414b6d}.LogRecordItem__content{position:relative;padding:.25rem 1.5rem .25rem 3.25rem;height:100%}.LogRecordItem__content:before{content:"";position:absolute;top:-.125rem;left:2.25rem;width:.0625rem;height:calc(100% + 8px);background-color:#dceafb}.LogRecordItem__content-title{padding:0 1.5rem}.LogRecordItem__content__item{border:.0625rem solid #dceafb;border-radius:.375rem;white-space:nowrap;display:flex;align-items:center;position:relative;height:100%}.LogRecordItem__content__item:before{content:"";position:absolute;left:-1rem;width:1rem;height:1px;background-color:#dceafb}.LogRecordItem__content__item__leftBox{display:flex;align-items:center;height:100%;width:110px;border-right:.0625rem solid #dceafb;padding:.25rem .375rem;background-color:#f2f5fa;border-top-left-radius:.375rem;border-bottom-left-radius:.375rem}.LogRecordItem__content__item__leftBox__statusBadge{width:24px;height:24px;border-radius:50%;display:flex;justify-content:center;align-items:center;background:none;margin-right:.375rem}.LogRecordItem__content__item__leftBox__content{display:flex;flex-direction:column;align-items:flex-start;justify-self:center}.LogRecordItem__content__item__leftBox__date{margin-right:.375rem;font-family:"Inconsolata",monospace;font-variation-settings:"wdth" 90}.LogRecordItem__content__item__leftBox .Table__status_indicator{margin-right:0}.LogRecordItem__content__item__itemBox{font-size:.75rem;background-color:rgba(247,250,255,.7);display:flex;flex-direction:column;flex:1 1;align-items:flex-start;max-width:calc(100% - 110px);height:100%;position:relative;padding:.25rem .5rem;overflow-x:auto;overflow-y:hidden;border-top-right-radius:.375rem;border-bottom-right-radius:.375rem}.LogRecordItem__content__item__itemBox__message{width:100%;max-width:100%;overflow:hidden;text-overflow:ellipsis;font-family:"Inconsolata",monospace;font-variation-settings:"wdth" 90}.LogRecordItem__content__item__itemBox__extraParams{display:flex;max-width:100%;max-height:95px;margin-top:.75rem;border:.0625rem solid #dceafb;background-color:#f2f5fa;border-radius:.375rem;-webkit-transform:scale(.85);transform:scale(.85);-ms-transform-origin-x:left;-ms-transform-origin-y:top;-webkit-transform-origin-x:left;-webkit-transform-origin-y:top;cursor:pointer}.LogRecordItem__content__item__itemBox__extraParams__dict{font-family:"Inconsolata",monospace;font-variation-settings:"wdth" 90;display:inline-block;position:relative;width:100%;max-width:100%;padding:.125rem .25rem;text-overflow:ellipsis;overflow:hidden;border-radius:.375rem;box-shadow:inset 0 -12px 20px -16px rgba(0,0,0,.1);transition:box-shadow .18s ease-out}.LogRecordItem__content__item__itemBox__extraParams__dict:hover{box-shadow:inset 0 -12px 20px -16px rgba(0,0,0,.2)}.LogRecordItem__content__item__itemBox__extraParams__dict:hover .LogRecordItem__content__item__itemBox__extraParams__dict__overflowHandler{opacity:1}.LogRecordItem__content__item__itemBox__extraParams__dict>div:first-of-type{pointer-events:none}.LogRecordItem__content__item__itemBox__extraParams__dict__overflowHandler{position:absolute;bottom:0;left:0;width:100%;padding:.25rem;display:flex;align-items:center;justify-content:center;border-bottom-left-radius:.375rem;border-bottom-right-radius:.375rem;opacity:0;transition:opacity .18s ease-out}.RunLogRecords{padding:1.5rem 0;height:100%}.RunLogRecords__contentWrapper{background:#fff;border:.0625rem solid #dee6f3;border-radius:.5rem;height:100%}.RunLogRecords__contentWrapper__listWrapper{height:100%;position:relative}.RunLogRecords__contentWrapper__listWrapper .overlay{display:none;height:3.125rem;width:100%;background:#fff;position:absolute;bottom:0;left:0}.RunLogRecords__contentWrapper__listWrapper .loading{display:flex;justify-content:center;align-items:center}
/*# sourceMappingURL=RunLogRecords.css?version=fdf4136b73ec04970a2d.map */