.TextsVisualizer{height:calc(100% - 50px);padding:.625rem 1.25rem 0;width:100%;position:relative}.TextsVisualizer__textCell{height:100%;padding:.75rem .5rem;overflow:auto}
/*# sourceMappingURL=TextsVisualizer.css?version=2110c04329184233a5a9.map */