.SliderWithInput{display:flex;align-items:center;height:100%;max-width:32.5rem;width:100%}.SliderWithInput__densityWrapper{height:100%;display:flex;flex-direction:column;justify-content:center}.SliderWithInput__densityWrapper__densityField{width:5.375rem;height:1.25rem;border:.0625rem solid #d1ddef;border-radius:.125rem;font-size:.625rem;font-weight:550;color:#414b6d;padding-left:.375rem}.SliderWithInput__densityWrapper__densityField::-webkit-inner-spin-button,.SliderWithInput__densityWrapper__densityField::-webkit-outer-spin-button{-webkit-appearance:none;margin:0}.SliderWithInput__densityWrapper__densityField[type=number]{-moz-appearance:textfield}.SliderWithInput__densityWrapper__densityField:focus-visible{outline:unset}.SliderWithInput__densityWrapper__densityTitleBox{display:flex}.SliderWithInput__densityWrapper__densityTitleBox__labelTooltip{background-color:#606986;width:.6875rem;height:.6875rem;color:#fff;font-size:.4375rem;display:flex;align-items:center;justify-content:center;border-radius:50%;margin-top:.0625rem;cursor:pointer}.SliderWithInput__densityWrapper__densityTitleBox__densityFieldLabel{margin-right:.16rem;min-width:4.4rem;margin-bottom:.1875rem}.SliderWithInput__sliderWrapper{max-width:24.875rem;width:100%;height:100%;display:flex;flex-direction:column;justify-content:space-between;margin-right:2rem;padding-bottom:.5rem}.SliderWithInput__sliderWrapper .Slider{padding-bottom:.1875rem}.SliderWithInput__sliderWrapper__sliderTitleBox{line-height:1.125rem}.SliderWithInput__sliderWrapper__title{margin-right:.25rem;font-size:.625rem;font-weight:350;color:#606986}.SliderWithInput__sliderWrapper__sliderValuesLabel{width:4.875rem;margin-right:.5rem}.RangePanel{height:3rem;background:#fff;border-top:.0625rem solid #e8f1fc;border-bottom-right-radius:.375rem}.RangePanel,.RangePanel .RangePanelContainer{display:flex;align-items:center;width:100%;justify-content:center}.RangePanel .RangePanelContainer{height:100%;max-width:85rem;padding:0 2.125rem}.RangePanel .RangePanelContainer .ApplyButtonContainer{height:100%;display:flex;align-items:center}.RangePanel .RangePanelContainer .ApplyButtonContainer .ApplyButton{height:1.5rem!important;width:5.125rem}.RangePanel .RangePanelContainer .VerticalDivider{width:.0625rem;height:1.5rem;background:#e8f1fc;margin-right:2.75rem;margin-left:2.75rem}.RangePanel .RangePanelContainer .InfoMassageBox{width:100%;display:flex;align-items:center;justify-content:center}.RangePanel .RangePanelContainer .InfoMassageBox i{margin-right:.75rem}.RangePanel .RangePanelContainer .InfoMassageBox .InfoMessageBoldText{margin:0 .1875rem}.TraceVisualizationWrapper{display:flex;width:100%;height:100%}.TraceVisualizationWrapper .VisualizationLoader{height:100%!important}.TraceVisualizationWrapper .MenuArea{max-width:23.75rem;min-width:20rem}.TraceVisualizationWrapper .Menu{background-color:#fff;border-bottom-left-radius:.5rem}.TraceVisualizationWrapper .VisualizerArea{width:100%;border:.0625rem solid #dee6f3;border-left:none;border-top-right-radius:.375rem;border-bottom-right-radius:.375rem;display:flex;flex-direction:column;justify-content:space-between;background-color:#fff}.TraceVisualizationWrapper .VisualizerArea__suspenseLoaderContainer{display:flex;justify-content:center;align-items:center;height:100%;width:100%}
/*# sourceMappingURL=TraceVisualizationContainer.css?version=b3091cd3e14c47845e26.map */