(this.webpackJsonpui_v2=this.webpackJsonpui_v2||[]).push([[24],{1958:function(e,t,a){},2006:function(e,t,a){"use strict";a.r(t);var i=a(0),l=a.n(i),s=a(11),d=a(191),n=(a(1958),a(1));function r(e){var t,a=l.a.useRef(null),i=[{dataKey:"step",key:"step",title:"Step",width:100},{dataKey:"index",key:"index",title:"Index",width:100},{dataKey:"text",key:"text",title:"Text",width:0,flexGrow:1,cellRenderer:function(e){var t=e.cellData;return Object(n.jsx)("div",{className:"ScrollBar__hidden TextsVisualizer__textCell",children:Object(n.jsx)("pre",{children:t})})}}];return Object(n.jsx)(s.a,{children:Object(n.jsx)("div",{className:"TextsVisualizer",children:Object(n.jsx)(d.a,{tableRef:a,tableData:null===e||void 0===e||null===(t=e.data)||void 0===t?void 0:t.processedValues,tableColumns:i,isLoading:null===e||void 0===e?void 0:e.isLoading,searchableKeys:["text"]})})})}r.displayName="TextsVisualizer";var c=l.a.memo(r);t.default=c}}]);
//# sourceMappingURL=TextsVisualizer.js.map?version=0f50080078c8c9e260f6