(this.webpackJsonpui_v2=this.webpackJsonpui_v2||[]).push([[14],{1959:function(a,e,i){},2007:function(a,e,i){"use strict";i.r(e);var l=i(0),s=i(1411),d=i.n(s),o=i(74),t=i(292),u=i(11),r=i(388),c=(i(1959),i(1));function n(a){var e,i,l,s,n,v,j;return Object(c.jsx)(u.a,{children:Object(c.jsx)(t.a,{className:"VisualizationLoader",isLoading:!!a.isLoading,children:Object(c.jsx)("div",{className:"PlotlyVisualizer",children:o.a.isEmpty(null===(e=a.data)||void 0===e?void 0:e.processedValue)?Object(c.jsx)(r.a,{size:"xLarge",title:"No Tracked Figures"}):Object(c.jsx)("div",{className:"PlotlyVisualizer__recordCnt",children:Object(c.jsx)(d.a,{data:null===(i=a.data)||void 0===i||null===(l=i.processedValue)||void 0===l?void 0:l.data,layout:null===(s=a.data)||void 0===s||null===(n=s.processedValue)||void 0===n?void 0:n.layout,frames:null===(v=a.data)||void 0===v||null===(j=v.processedValue)||void 0===j?void 0:j.frames,useResizeHandler:!0})})})})})}n.displayName="PlotlyVisualizer";var v=Object(l.memo)(n);e.default=v}}]);
//# sourceMappingURL=PlotlyVisualizer.js.map?version=afc564209a0eb2444838