.ConfirmModal .MuiBackdrop-root{background-color:rgba(0,0,0,.4)}.ConfirmModal .MuiPaper-rounded{border-radius:6px}.ConfirmModal .MuiPaper-elevation10{box-shadow:0 2px 4px #767a80}.ConfirmModal__Body{min-width:384px;padding:24px}.ConfirmModal__Body .ConfirmModal__Title__Container{display:flex;align-items:center;margin-bottom:12px}.ConfirmModal__Close__Icon{position:absolute;right:10px;top:10px}.ConfirmModal__Icon{display:flex;justify-content:center;align-items:center;width:32px;height:32px;margin-right:16px;border-radius:50%}.ConfirmModal__Icon .Icon__container{font-size:14px}.ConfirmModal__CancelButton{margin-right:10px;color:#1c2852}.ConfirmModal__Footer{padding:16px;margin:0 8px;border-top:1px solid #dee6f3;display:flex;justify-content:flex-end;align-items:center}.ConfirmModal__error .ConfirmModal__Icon{background-color:#fdeded}.ConfirmModal__error .ConfirmModal__Icon .Icon__container{color:#e64e48}.ConfirmModal__error .ConfirmModal__ConfirmButton{background-color:#e64e48}.ConfirmModal__warning .ConfirmModal__Icon{background-color:#fffae6}.ConfirmModal__warning .ConfirmModal__Icon .Icon__container{color:#fc0}.ConfirmModal__warning .ConfirmModal__ConfirmButton{background-color:#fc0}.ConfirmModal__success .ConfirmModal__Icon{background-color:#eaf9f3}.ConfirmModal__success .ConfirmModal__Icon .Icon__container{color:#2bc784}.ConfirmModal__success .ConfirmModal__ConfirmButton{background-color:#2bc784}.ConfirmModal__info .ConfirmModal__Icon{background-color:#e8f1fc}.ConfirmModal__info .ConfirmModal__Icon .Icon__container{color:#1473e6}.ConfirmModal__info .ConfirmModal__ConfirmButton{background-color:#1473e6}.RunDetailNotesTab{padding:1.5rem 0;height:100%}.RunDetailNotesTab .isLoading .ProseMirror{opacity:0}.RunDetailNotesTab__Editor{height:100%;position:relative}.RunDetailNotesTab__Editor__actionPanel{display:flex;background-color:#f2f5fa;justify-content:space-between;padding:.5rem 1.5rem;border-radius:.5rem .5rem 0 0;border:.0625rem solid #dee6f3}.RunDetailNotesTab__Editor__actionPanel__info,.RunDetailNotesTab__Editor__actionPanel__info-field{display:flex;align-items:center}.RunDetailNotesTab__Editor__actionPanel__info-field i{margin-right:.75rem}.RunDetailNotesTab__Editor__actionPanel__info-field:first-child{margin-right:1rem}.RunDetailNotesTab__Editor__actionPanel__saveBtn.Mui-disabled{color:#fff!important}.RunDetailNotesTab__Editor__container{justify-content:start!important;height:calc(100% - 44px)}.RunDetailNotesTab__Editor__container>div:first-child{height:100%;border-radius:0 0 .5rem .5rem;border:.0625rem solid #dee6f3;border-top:0}.RunDetailNotesTab__Editor .ProseMirror{font-size:1rem;padding:1rem 2rem 1rem 3rem;font-family:"Inter",sans-serif;font-weight:450;height:100%;opacity:1;color:#1c2852;transition:opacity .18s ease-out;overflow:auto}.RunDetailNotesTab__Editor .ProseMirror .block-menu-trigger{margin-left:-1.6875rem}.RunDetailNotesTab__Editor .ProseMirror .block-menu-trigger:hover{color:#414b6d}.RunDetailNotesTab__Editor .ProseMirror code{font-size:100%}.RunDetailNotesTab__Editor .ProseMirror input{background-color:unset}.RunDetailNotesTab__Editor .ProseMirror a{color:#1473e6}.RunDetailNotesTab__Editor .ProseMirror-selectednode{outline:.0625rem solid #89b9f2!important}.RunDetailNotesTab__Editor .ProseMirror hr:before{border-top:.0625rem solid #bdcee8}.RunDetailNotesTab__Editor .ProseMirror .page-break:before{border-top:.0625rem dashed #bdcee8}.RunDetailNotesTab__Editor .ProseMirror .heading-actions{display:none}.RunDetailNotesTab__Editor .ProseMirror h1:before,.RunDetailNotesTab__Editor .ProseMirror h2:before,.RunDetailNotesTab__Editor .ProseMirror h3:before,.RunDetailNotesTab__Editor .ProseMirror h4:before{content:unset!important;display:none!important}.RunDetailNotesTab__Editor .ProseMirror mark{background-color:#fffac1;color:#1c2852}.RunDetailNotesTab__Editor .ProseMirror h1{font-size:2.25rem}.RunDetailNotesTab__spinnerWrapper{position:absolute;height:100%;width:100%;display:flex;justify-content:center;align-items:center;top:0;left:0}#block-menu-container{box-shadow:0 .25rem .375rem rgba(144,175,218,.2);border:.0625rem solid #e8f1fc}#block-menu-container svg{fill:#414b6d}#notes-toolbar-popover{box-shadow:0 .25rem .375rem rgba(144,175,218,.2);border:.0625rem solid #ebf0f8}#notes-toolbar-popover:before{content:unset!important}
/*# sourceMappingURL=RunDetailNotesTab.css?version=ef981da89f31e2e0d2f1.map */