.AudioPlayer{max-width:16.75rem}.AudioPlayer__controllers{position:relative;display:flex;align-items:center;padding:.5rem;background-color:#f4f4f6;border-radius:.375rem;width:16.75rem;height:2.5rem}.AudioPlayer__controllers__player{position:relative;display:flex;align-items:center;justify-content:center}.AudioPlayer__controllers__player .Icon__container{position:absolute;z-index:0;font-size:.75rem}.AudioPlayer__controllers__player .MuiPaper-root{height:1.5rem;width:1.5rem;display:flex;align-items:center;justify-self:center;background-color:initial;box-shadow:unset}.AudioPlayer__controllers__player .MuiPaper-root .MuiGrid-root{padding:0;display:flex}.AudioPlayer__controllers__player .MuiPaper-root .MuiGrid-root svg{font-size:1.5rem;color:transparent;z-index:1;position:relative}.AudioPlayer__controllers__player .MuiPaper-root .MuiGrid-root svg:hover{color:transparent}.AudioPlayerProgress{display:flex;align-items:center;width:100%}.AudioPlayerProgress__timer{display:flex}.AudioPlayerProgress__timer span{width:2rem;text-align:right;font-family:"Inconsolata",monospace;font-variation-settings:"wdth" 82}.AudioPlayerProgress__timer span:last-child{text-align:left}.AudioPlayerProgress__timer-long{min-width:4.625rem}.AudioPlayerProgress__timer-long span{min-width:2.5rem;text-align:right;display:inline-block}.AudioPlayerProgress__timer-long span:last-child{text-align:left}.AudioPlayerProgress__progressSlider{margin:0 .25rem 0 .375rem;height:2.5rem;flex:1 1;overflow:hidden}.AudioPlayerProgress__progressSlider .MuiSlider-root{height:100%!important}.AudioPlayerProgress__progressSlider.Slider:hover .MuiSlider-thumb{opacity:1;visibility:visible;margin-top:0}.AudioPlayerProgress__progressSlider.Slider:hover .Mui-disabled .MuiSlider-thumb{opacity:0;visibility:hidden}.AudioPlayerProgress__progressSlider.Slider .MuiSlider-root{height:.375rem;display:flex;align-items:center}.AudioPlayerProgress__progressSlider.Slider .MuiSlider-thumb{width:.5rem;height:.5rem;box-shadow:unset;margin-top:0;transition:opacity .18s ease-out;opacity:0;visibility:hidden}.AudioPlayerProgress__progressSlider.Slider .MuiSlider-thumb:hover{box-shadow:unset}.AudioPlayerProgress__progressSlider.Slider .MuiSlider-thumb:after{width:1.125rem;height:1.375rem;top:-.375rem;left:-.3125rem}.AudioPlayerVolume{margin:0 .375rem 0 .5rem;position:relative}.AudioPlayerVolume__button{justify-content:flex-start}.AudioPlayerVolume:hover .AudioPlayerVolume__slider{opacity:1;visibility:visible}.AudioPlayerVolume__slider{background-color:#f4f4f6;opacity:0;visibility:hidden;transition:all .18s ease-out;bottom:-1rem;left:0;position:absolute;width:3.5rem;box-shadow:0 .125rem .25rem rgba(28,40,82,.15);border-radius:.125rem;height:1rem;display:flex;justify-content:center;align-items:center;z-index:2}.AudioPlayerVolume__slider .SliderThumb{width:6px;height:6px}.AudioPlayerVolume__slider .SliderThumb:after{top:1px;left:1px}.Illustration{display:flex;justify-content:center;align-items:center;width:100%;height:100%;overflow:auto;flex-direction:column}.Illustration__hidden{display:none}.Illustration__container{height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;overflow:hidden;padding-bottom:7rem}.Illustration__container__content{text-align:center}.Illustration__container__content .qlAnchor{color:#1473e6;text-decoration:none;margin:0 .25rem}.Illustration__container__content .qlAnchor:hover{text-decoration:underline}.Illustration__container__img{text-align:center}.Illustration__container__img>img,.Illustration__container__img>svg{margin:0 auto;display:block}.Illustration__container__img__small{padding:.5rem}.Illustration__container__img__small>img,.Illustration__container__img__small>svg{width:3rem;height:auto}.Illustration__container__img__medium{padding:.75rem}.Illustration__container__img__medium>img,.Illustration__container__img__medium>svg{width:7.5rem;height:auto}.Illustration__container__img__large{padding:.75rem}.Illustration__container__img__large>img,.Illustration__container__img__large>svg{width:14.5rem;height:auto}.Illustration__container__img__xLarge{padding:1rem}.Illustration__container__img__xLarge>img,.Illustration__container__img__xLarge>svg{width:19.5rem;height:auto}.AppBar{display:flex;align-items:center;min-height:2.5rem;max-height:2.5rem;border-bottom:.0625rem solid #e8f1fc;border-left:.0625rem solid #e8f1fc;border-right:.0625rem solid #e8f1fc;padding-left:1.5rem;background:#fff;z-index:1}.AppBar__title{flex:1 1;text-transform:uppercase;letter-spacing:.07em}.AppBar__content{display:flex;align-items:center}.AppBar__content--disabled{pointer-events:none;opacity:.5}
/*# sourceMappingURL=Reports.css?version=4cd85496e3c131e290db.map */